@@ -10,9 +10,9 @@ class Ticker:
     """Delivery of ticks at intervals.
 
     Once started the `Ticker` will periodically make a boolean "tick" of True
-    available through the `tick` method. Uncollected ticks will not stack or queue
-    up, and the Ticker will continue to tick regardless. When stopped `tick` will
-    return False, and any uncollected tick will be lost.
+    available through the `tick` method. Uncollected ticks will not stack or
+    queue up, and the Ticker will continue to tick regardless. When stopped
+    `tick` will return False, and any uncollected tick will be lost.
 
     Example::
 
@@ -42,11 +42,12 @@ class Ticker:
             self._lock.release()
             time.sleep(interval)
 
-    def start(self, interval: int) -> None:
+    def start(self, interval: int, immediate: bool = False) -> None:
         """Start the ticker.
 
         Args:
             interval: Time between ticks.
+            immediate: Start the ticker with a tick delivery.
 
         Raises:
             Exception if already running.
@@ -56,6 +57,8 @@ class Ticker:
         if self._tick:
             raise RuntimeError("Ticker already started")
         self._tick = queue.LifoQueue(2)
+        if immediate:
+            self._tick.put(True)
         self._lock.release()
         thread = threading.Thread(target=self._schedule, args=(interval,), daemon=True)
         thread.start()
